require_dependency 'docs_api/application_controller'

module DocsApi
  class DocsController < ApplicationController
    def index
      @versions = []
      doc_dir = Rails.root.join('app', 'docs', '*')
      Dir.glob(doc_dir).each do |entry|
        @versions.push(entry.split('/').last) if File.directory? entry
      end
    end

    def show
      docs = Dir.glob(Rails.root.join('app', 'docs', params[:id], '*.md'))
      raise ActiveRecord::RecordNotFound if docs.blank?

      url = request.protocol + request.host_with_port
      @api_text = "FORMAT: 1A\nHOST: #{url}\n# API: #{url}\n"
      intro_path = Rails.root.join('app', 'docs', params[:id], '_introduction.md')

      @api_text += if File.exists?(intro_path)
                     File.read(intro_path)
                   else
                     'API doc'
                   end
      @api_text += "\n\n"

      docs.sort_by { |d| d.split('/').last }.each do |doc|
        @api_text += File.read(doc) + "\n" unless doc =~ /introduction.md\z/i
      end
    end
  end
end
